from .area_code import (
    area_code_2,
    area_code_3,
    area_code_4,
    area_code_5,
)

from .defined_code import (
    TOTAL_CODE_LENGTH,
    MOBILE_CODE_PREFIX_LENGTH,
    MOBILE_CODE_LENGTH,
    FREEDIAL_CODE_PREFIX_LENGTH,
    FREEDIAL_CODE_LENGTH,
    OTHER_CODE_PREFIX_LENGTH,
    OTHER_CODE_LENGTH,

    mobile_code,
    freedial_code,
    other_code,
)

__all__ = [
    area_code_2,
    area_code_3,
    area_code_4,
    area_code_5,

    TOTAL_CODE_LENGTH,
    MOBILE_CODE_PREFIX_LENGTH,
    MOBILE_CODE_LENGTH,
    FREEDIAL_CODE_PREFIX_LENGTH,
    FREEDIAL_CODE_LENGTH,
    OTHER_CODE_PREFIX_LENGTH,
    OTHER_CODE_LENGTH,

    mobile_code,
    freedial_code,
    other_code,
]
