TOTAL_CODE_LENGTH = 6
MOBILE_CODE_PREFIX_LENGTH = 3
MOBILE_CODE_LENGTH = 4
FREEDIAL_CODE_PREFIX_LENGTH = 4
FREEDIAL_CODE_LENGTH = 3
OTHER_CODE_PREFIX_LENGTH = 4
OTHER_CODE_LENGTH = 3

mobile_code = [
    '050',  # IP電話
    '070',  # 携帯電話/PHS
    '080',  # 携帯電話
    '090',  # 携帯電話
    '020',  # その他
]

freedial_code = [
    '0120',  # フリーダイヤル 0120-xxx-xxx
    '0800',  # フリーダイヤル 0800-xxx-xxxx
]

other_code = [
    '0570',  # ナビダイヤル 0570-xxx-xxx
    '0990',  # ダイヤルQ2 0990-xxx-xxx
]
